import React from 'react';
import { Button, Input, List, Popconfirm, Spin, Modal, message } from 'antd';
import useBool from '@/utils/hooks/useBool';
import classNames from 'classnames';
import {
  getRoleList,
  getRoleDetail,
  saveRole,
  updateRole,
  deleteRole,
} from '@/services/role';
import './style.less';

const Header = (props) => {
  return (
    <div className='role-list-header'>
      <div className='role-list-header-body'>{props.children}</div>
      <div className='role-list-header-action'>{props.action}</div>
    </div>
  )
}

export default (props) => {
  const { current, onChange } = props;

  const [loading, startLoading, cancelLoading] = useBool();
  const [visible, openModel, hideModel] = useBool();
  const [inText, setInText] = React.useState();
  const [list, setList] = React.useState([]);

  const onAdd = () => {
    openModel();
    setInText();
    onChange();
  }

  const onEdit = (item) => {
    openModel();
    setInText(item.name);
    onChange(item);
  }

  const onDelete = (item) => {
    startLoading();
    // 删除角色
    deleteRole(item.id).then(() => {
      setList(list.filter(x => x.id !== item.id));
      cancelLoading();
      hideModel();
      onChange();
    }).catch(() => {
      cancelLoading();
    })
  }

  const handleOk = () => {
    if (!inText) {
      message.warn('请输入角色名称');
      return;
    }
    startLoading();
    const data = { name: inText };

    if (currentRef.current) {
      // 修改角色
      updateRole(currentRef.current.id, data).then(res => {
        setList(list.map(x => x.id === currentRef.current.id ? res : x));
        cancelLoading();
        hideModel();
      }).catch(() => {
        cancelLoading();
      })
    } else {
      // 新增角色
      saveRole(data).then((res) => {
        setList([res].concat(list));
        cancelLoading();
        hideModel();
        onChange(res);
      }).catch(() => {
        cancelLoading();
      })
    }
  }

  const handleCancel = () => {
    if (loading) {
      return ;
    }

    hideModel();
  }

  React.useEffect(() => {
    startLoading();
    getRoleList().then((res = []) => {
      setList(res);
      cancelLoading();
    }).catch(() => {
      cancelLoading();
    });
  }, []);

  return (
    <Spin spinning={loading}>
      <List
        header={<Header action={<Button type='primary' onClick={onAdd}>新增</Button>}>角色列表</Header>}
        style={{ background: '#fff' }}
        bordered
        dataSource={list}
        renderItem={item => (
          <List.Item
            className={classNames('role-list-item', { active: current && current.id === item.id })}
            onClick={() => onChange(item)}
            actions={[
              <Button key='edit' type='link' onClick={() => onEdit(item)}>编辑</Button>,
              <Popconfirm key='delete' title="确认删除?" onConfirm={() => onDelete(item)}>
                <Button type='link' danger>删除</Button>
              </Popconfirm>
            ]}
          >
            {item.name}
          </List.Item>
        )}
      />
      <Modal
        title="请输入角色名称"
        open={visible}
        onOk={handleOk}
        onCancel={handleCancel}
      >
        <Input value={inText} onChange={e => setInText(e.target.value)} />
      </Modal>
    </Spin>
  )
}
