import React from 'react';
import * as echarts from 'echarts/core';
import icon from '@/assets/images/statistic/设备分类统计.png';
import Chart from '@/components/chart';
import StatisCard from './StatisCard';

let dataIndex = 0;

export default (props) => {

  const chartRef = React.useRef();
  const option = getOption({ "制餐设备": 20, "运输设备": 33, "野外保障设备": 10 });

  React.useEffect(() => {
    const t = setTimeout(() => {
      const chart = chartRef.current;
      chart.on('mousemove', function(e) {
        chart.dispatchAction({ type: 'downplay', dataIndex });
        chart.dispatchAction({ type: 'highlight', dataIndex: e.dataIndex });
        dataIndex = e.dataIndex
      });
      chart.dispatchAction({ type: 'highlight', dataIndex });
      clearTimeout(t);
    }, 300);
  }, []);

  const onInited = (chart) => chartRef.current = chart;

  return (
    <StatisCard
      title="设备分类统计"
      icon={icon}
    >
      <Chart option={option} style={{ height: '300px' }} onInited={onInited} />
    </StatisCard>
  )
}

function getOption(seriesData) {
  const data = Object.keys(seriesData).map(function(key) {
    return {
      value: seriesData[key],
      name: key
    }
  });

  return {
    color: ['#3DE0A4', '#FF8940', '#3FC9F4', '#CB55E9'],
    series: [
      {
        name: '设备分类统计',
        type: 'pie',
        radius: ['40%', '70%'],
        avoidLabelOverlap: false,
        itemStyle: {
          borderRadius: 10,
          borderColor: '#071C51',
          borderWidth: 4
        },
        label: {
          show: false,
          position: 'center',
        },
        emphasis: {
          scaleSize: 16,
          label: {
            show: true,
            color: '#ffffff',
            fontSize: 16,
            fontWeight: 'bold',
            lineHeight: 24,
            formatter: function (params) {
              return params.name + '\n' + params.value
            },
          }
        },
        labelLine: {
          show: false
        },
        data: data,
      }
    ]
  };
}